@@ -102,6 +102,7 @@ extern struct gpasm_state {
   gp_boolean found_devid;	/* config directive in source code */
   gp_boolean found_idlocs;	/* idlocs directive in source code */
   unsigned int maxram;		/* Highest legal memory location */
+  long maxrom;			/* Highest legal program memory location */
   enum outfile
     codfile,			/* Symbol output file control */
     depfile,			/* Dependency output file control */
@@ -203,6 +204,7 @@ extern struct gpasm_state {
   struct file_context *files;   /* Top of the stack of all files */
   struct amode *astack;		/* Stack of amodes (macros, etc) */
   gpasmVal cblock;		/* cblock constant */
+  int cblock_defined;
   struct macro_head *mac_head;  /* Starting a macro... */
   struct macro_body **mac_prev; /* Stitching ptr */
   struct macro_body *mac_body;	/* While we're building a macro */
@@ -294,6 +296,7 @@ int stringtolong(char *string, int radix);
 int gpasm_magic(char *);
 char *convert_escape_chars(char *ps, int *value);
 char *convert_escaped_char(char *str, char c);
+void coerce_str1(struct pnode *exp);
 gpasmVal do_or_append_insn(char *op, struct pnode *parms);
 void set_global(char *name,
 		gpasmVal value,
