@@ -1,7 +1,9 @@
-/* A Bison parser, made by GNU Bison 1.875c.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,13 +17,21 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -40,7 +50,7 @@
      NUMBER = 266,
      PROCESSOR = 267,
      STRING = 268,
-     INCLUDE = 269,
+     DEFINE = 269,
      UPPER = 270,
      HIGH = 271,
      LOW = 272,
@@ -75,6 +85,7 @@
      VAR_END = 301
    };
 #endif
+/* Tokens.  */
 #define LABEL 258
 #define IDENTIFIER 259
 #define CBLOCK 260
@@ -86,7 +97,7 @@
 #define NUMBER 266
 #define PROCESSOR 267
 #define STRING 268
-#define INCLUDE 269
+#define DEFINE 269
 #define UPPER 270
 #define HIGH 271
 #define LOW 272
@@ -123,15 +134,17 @@
 
 
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
 #line 225 "parse.y"
-typedef union YYSTYPE {
+{
   gpasmVal i;
   char *s;
   struct pnode *p;
-} YYSTYPE;
-/* Line 1275 of yacc.c.  */
-#line 135 "parse.h"
+}
+/* Line 1489 of yacc.c.  */
+#line 147 "parse.h"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -139,5 +152,3 @@ typedef union YYSTYPE {
 
 extern YYSTYPE yylval;
 
-
-
