@@ -178,6 +178,23 @@ convert_escape_chars(char *ps, int *value)
 
 }
 
+/* In some contexts, such as in the operand to a literal instruction, a
+ * single-character string literal in an expression can be coerced to a
+ * character literal. coerce_str1 converts a string-type pnode to a
+ * constant-type pnode in-place. */
+void coerce_str1(struct pnode *exp)
+{
+  if ((exp != NULL) && (exp->tag == string)) {
+    int value;
+    char *pc = convert_escape_chars(exp->value.string, &value);
+    if (*pc == '\0') {
+      /* castable string, make the conversion */
+      exp->tag = constant;
+      exp->value.constant = value;
+    }
+  }
+}
+
 void set_global(char *name,
                 gpasmVal value,
                 enum globalLife lifetime,
@@ -202,6 +219,21 @@ void set_global(char *name,
     var->coff_section_num = state.obj.section_num;
     var->type = type;
     var->previous_type = type;  /* coff symbols can be changed to global */
+
+    /* increment the index into the coff symbol table for the relocations */
+    switch(type) {
+    case gvt_extern:
+    case gvt_global:
+    case gvt_static:
+    case gvt_address:
+    case gvt_debug:
+    case gvt_absolute:
+      state.obj.symbol_num++;
+      break;
+    default:
+      break;
+    }
+
   } else if (lifetime == TEMPORARY) {
     /*
      * TSD - the following embarrassing piece of code is a hack
@@ -235,20 +267,6 @@ void set_global(char *name,
       free(coff_name);
   }
 
-  /* increment the index into the coff symbol table for the relocations */
-  switch(type) {
-  case gvt_extern:
-  case gvt_global:
-  case gvt_static:
-  case gvt_address:
-  case gvt_debug:
-  case gvt_absolute:
-    state.obj.symbol_num++;
-    break;
-  default:
-    break;
-  }
-
 }
 
 void select_errorlevel(int level)
