@@ -44,6 +44,8 @@ enum pic_processor {
   pic10f202,
   pic10f204,
   pic10f206,
+  pic10f220,
+  pic10f222,
   pic12c508,
   pic12c508a,
   pic12c509,
@@ -57,6 +59,7 @@ enum pic_processor {
   pic12cr509a,
   pic12f508,
   pic12f509,
+  pic12f510,
   pic12f629,
   pic12f635,
   pic12f675,
@@ -118,7 +121,6 @@ enum pic_processor {
   pic16c73b,
   pic16c74,
   pic16c745,
-  pic16c747,
   pic16c74a,
   pic16c74b,
   pic16c76,
@@ -160,6 +162,7 @@ enum pic_processor {
   pic16f54,
   pic16f57,
   pic16f59,
+  pic16f610,
   pic16f627,
   pic16f627a,
   pic16f628,
@@ -180,6 +183,7 @@ enum pic_processor {
   pic16f73,
   pic16f737,
   pic16f74,
+  pic16f747,
   pic16f76,
   pic16f767,
   pic16f77,
@@ -203,6 +207,11 @@ enum pic_processor {
   pic16f877,
   pic16f877a,
   pic16f88,
+  pic16f882,
+  pic16f883,
+  pic16f884,
+  pic16f886,
+  pic16f887,
   pic16f913,
   pic16f914,
   pic16f916,
@@ -230,7 +239,9 @@ enum pic_processor {
   pic18c801,
   pic18c858,
   pic18f1220,
+  pic18f1230,
   pic18f1320,
+  pic18f1330,
   pic18f2220,
   pic18f2320,
   pic18f2331,
@@ -242,6 +253,7 @@ enum pic_processor {
   pic18f2455,
   pic18f248,
   pic18f2480,
+  pic18f24j10,
   pic18f2510,
   pic18f2515,
   pic18f252,
@@ -252,10 +264,13 @@ enum pic_processor {
   pic18f258,
   pic18f2580,
   pic18f2585,
+  pic18f25j10,
   pic18f2610,
   pic18f2620,
   pic18f2680,
   pic18f2681,
+  pic18f2682,
+  pic18f2685,
   pic18f4220,
   pic18f4320,
   pic18f4331,
@@ -267,6 +282,7 @@ enum pic_processor {
   pic18f4455,
   pic18f448,
   pic18f4480,
+  pic18f44j10,
   pic18f4510,
   pic18f4515,
   pic18f452,
@@ -277,10 +293,13 @@ enum pic_processor {
   pic18f458,
   pic18f4580,
   pic18f4585,
+  pic18f45j10,
   pic18f4610,
   pic18f4620,
   pic18f4680,
   pic18f4681,
+  pic18f4682,
+  pic18f4685,
   pic18f6310,
   pic18f6390,
   pic18f6410,
@@ -326,7 +345,9 @@ enum pic_processor {
   rf675k,
   sx18,
   sx20,
-  sx28
+  sx28,
+  sx48,
+  sx52
 };
 
 #define MAX_NAMES 3 /* Maximum number of names a processor can have */
@@ -339,6 +360,7 @@ struct px {
   unsigned long coff_type; 
   int num_pages;
   int num_banks;
+  long maxrom;
   char *script;
 };
 
@@ -397,7 +419,8 @@ int gp_processor_set_page(enum proc_class class,
                           int num_pages,
                           int page,
                           MemBlock *m, 
-                          int address);
+                          int address,
+                          int use_wreg);
 int gp_processor_set_bank(enum proc_class class, 
                           int num_banks,
                           int bank,
